Many people have asked me to comment on a recent poster of a study from the American Heart Association (AHA) that purports to have discovered a link between time-restricted feeding (TRF) and cardiovascular disease (CVD) mortality (https://newsroom.heart.org/news/8-hour-time-restricted-eating-linked-to-a-91-higher-risk-of-cardiovascular-death). Essentially the study broke the cohort up into five non-uniform quintiles of feeding window duration: <8h, 8-<10h, 10-<12h, 12-16h, and >16h. Participants with a mean age of 48 were followed for eight years time, and it was apparently discovered that those eating in a window of less than eight hours per day almost doubled their risk of dying due to CVD.

I'll start of by saying that the study itself is not the most impressive piece of epidemiology I've ever seen, and I remain skeptical that we're observing a genuine causal relationship. Let me explain. While the study did include a large sample size of over 20,000 participants, it's important to note some key limitations. Firstly, the population data comes from the National Health and Nutrition Examination Survey (NHANES) dataset, which didn't use very rigorous measurements of dietary intake (https://www.cdc.gov/nchs/nhanes/measuring_guides_dri/measuringguides.htm). In fact, it's not entirely clear how they extracted feeding window data from the NHANES dataset at all, since the diet-related data just contains two 24-hour dietary recalls as their measurement of food intake between 2003 and 2018.

Before we go further into my criticisms, let's discuss a few of the findings. Essentially, Eight-hour TRE was not linked to reductions in all-cause or cancer mortality when compared to other eating windows durations. A significant association was found between the <8h TRE window and a higher risk of CVD mortality. This was true both in the general population and among individuals with preexisting CVD or cancer. Lastly, eating durations exceeding 16 hours per day were associated with a lower risk of cancer mortality in people with cancer. Which is actually understandable, since a significant causes of death in cancer patients is wasting due to cachexia (https://pubmed.ncbi.nlm.nih.gov/25291291/).

Now let's go over some issues. As previously mentioned, one of the biggest issues is the quality of the dietary assessment and the lack of clarity about how the feeding windows were ascertained. But, even if we grant that the dietary and feeding window measurements were precise and accurate, we still would have a good reason to question the results. Firstly, the adjustment model, while admittedly comprehensive by conventional standards in nutritional epidemiology, lacked at least one key confounder. For example, there is no adjustment for occupation, which makes shiftwork a potential confounder that went unaccounted for. Shiftwork can limit one's access to food (and opportunities to eat it even if there is access), forcing individuals to shorten their feeding window. But shiftwork also increases the risk of CVD (https://pubmed.ncbi.nlm.nih.gov/29247501/).

Another concerning issue is that the sample size for the <8h quintile was only 414 participants out of a total sample of >20,000, and only seeing 31 events. That's only 2.1% of the total study population. This could drastically influence the reliability of the risk estimate for this group. The bulk of the participants landed in the reference quintile of 12-16h, at 11,831 participants. There also wasn't a clear dose-response, with the 8-<10h and 10-<12h quintiles not being statistically significantly different from the reference quintile. I just don't have a lot of confidence in the sample size. Lastly, another issue is the population's mean age. Overall, participants were an average of 48 years old, but the <8h quintile was almost seven years younger at 41 years old on average. CVD deaths are far less prevalent at this age, which can easily inflate the relative risk, making a potential statistical anomaly appear more severe than it rightfully is.

Just for flavour, there is one other reason to doubt the findings, and it's a reason that is even mentioned by the authors themselves. From the randomized controlled trials (RCTs) that have been done on TRF, we don't have a good reason to believe that such a population would be at an increased risk of CVD to begin with. If anything, we'd expect such a population of people to have a lower overall risk of CVD (https://pubmed.ncbi.nlm.nih.gov/31808043/)(https://www.researchgate.net/publication/353140261_Effect_of_Time-Restricted_Feeding_on_Body_Weight_and_Cardiometabolic_Risks_A_Systematic_Review_and_Meta-Analysis_of_Randomized_Controlled_Trials). Overall there are, in my opinion, good reasons to doubt the findings, and there are other explanations for the relationship that seem altogether more plausible.

In light of the methodological challenges, small sample size for the key group, and conflicting evidence from prior randomized controlled trials, the study's claim of a near-doubling in cardiovascular disease mortality risk with an 8-hour time-restricted feeding pattern should be interpreted with caution. Further rigorous research is necessary to validate these findings and clarify the true impact of time-restricted feeding on long-term cardiovascular health.

**Key points:**

- Reliance on NHANES dataset with 24-hour dietary recalls may not accurately measure TRF, and lack of adjustment for shift work could skew results.

- The <8h TRF group was a small fraction of the study, potentially affecting the reliability of CVD mortality risk findings.

- The study's conclusion that TRF increases CVD mortality contradicts evidence from other RCTs suggesting cardiometabolic benefits of TRF.

#patreon_articles 
#nutrition 
#time_restricted_feeding